@@ -39,7 +39,11 @@ def default_page_layout(menu, *content):
             ShellHeader(
                 hg.C("PLATFORMNAME"),
                 hg.C("COMPANYNAME"),
-                searchbar=hg.F(lambda c: c.get("SEARCHBAR", "")),
+                searchbar=hg.If(
+                    hg.C("request.user.is_authenticated"),
+                    hg.C("SEARCHBAR"),
+                    "",
+                ),
             ),
             hg.If(
                 hg.C("request.user.is_authenticated"),
@@ -62,9 +66,9 @@ def default_page_layout(menu, *content):
             hg.If(
                 settings.DEBUG,
                 hg.BaseElement(
-                    hg.SCRIPT(src=_static("js/main.js")),
                     hg.SCRIPT(src=_static("js/bliss.js")),
                     hg.SCRIPT(src=_static("js/htmx.js")),
+                    hg.SCRIPT(src=_static("js/main.js")),
                     hg.SCRIPT(
                         src=_static("design/carbon_design/js/carbon-components.js")
                     ),
